
# Slot: symmetric


True means that any instance of  d s r implies that there is also an instance of r s d

URI: [linkml:symmetric](https://w3id.org/linkml/symmetric)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
